@@ -1,9 +1,9 @@
-# $Id: Runtime.pm,v 1.10 2002/06/17 13:51:39 joern Exp $
+# $Id: Runtime.pm,v 1.2 2004/05/11 08:59:36 joern Exp $
 
 package CIPP::Runtime;
 
-$REVISION = q$Revision: 1.10 $;
-$VERSION = "0.41";
+$REVISION = q$Revision: 1.2 $;
+$VERSION = "0.42";
 
 use strict;
 use FileHandle;
@@ -419,19 +419,19 @@ sub Open_Database_Connection {
 
 	croak "sql_open\t$DBI::errstr\n$@" if $DBI::errstr or $@ or not $dbh;
 	
-	if ( $$init ) {
+	if ( defined $init and $$init ) {
 		$dbh->do ( $$init );
 		die "database_initialization\t$DBI::errstr" if $DBI::errstr;
 	}
 
-	if ( $$init_perl ) {
+	if ( defined $init_perl and $$init_perl ) {
 		eval_init_perl (
 			code_sref => $init_perl,
 			dbh       => $dbh,
 		);
 	}
 	
-	if ( $$cache_enable ) {
+	if ( defined $cache_enable and $$cache_enable ) {
 		# cache handle, if caching is enabled
 		$DBH_CACHE{$cache_key} = $dbh;
 
